==> jc-1.4.0.tar.gz: polyglot/util/Position.h <==
// public class polyglot.util.Position

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Position_H_
#define _JC_polyglot_util_Position_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_util_Position$sub_refs	_jc_polyglot_util_Position$sub_refs;
typedef struct _jc_polyglot_util_Position$sub_nonrefs	_jc_polyglot_util_Position$sub_nonrefs;
typedef struct _jc_polyglot_util_Position$refs	_jc_polyglot_util_Position$refs;
typedef struct _jc_polyglot_util_Position$nonrefs	_jc_polyglot_util_Position$nonrefs;
typedef struct _jc_polyglot_util_Position$object	_jc_polyglot_util_Position$object;

typedef struct _jc_polyglot_util_Position$fields_struct	_jc_polyglot_util_Position$fields_struct;
typedef const struct _jc_polyglot_util_Position$vmethods	_jc_polyglot_util_Position$vmethods;
typedef const struct _jc_polyglot_util_Position$vtable	_jc_polyglot_util_Position$vtable;
typedef const struct _jc_polyglot_util_Position$vtype	_jc_polyglot_util_Position$vtype;

// Class fields structure
struct _jc_polyglot_util_Position$fields_struct {
	struct _jc_polyglot_util_Position$object	*COMPILER__5fGENERATED;
	jlong	serialVersionUID;
	jint	UNKNOWN;
};
extern _jc_polyglot_util_Position$fields_struct _jc_polyglot_util_Position$class_fields;

// Constructors
extern void _jc_polyglot_util_Position$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Position$object *);
extern void _jc_polyglot_util_Position$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_util_Position$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_polyglot_util_Position$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual methods
extern jint _jc_polyglot_util_Position$method$column$370206cd3cb25d90(_jc_env *, struct _jc_polyglot_util_Position$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Position$method$file$4a28a30360790222(_jc_env *, struct _jc_polyglot_util_Position$object *);
extern jint _jc_polyglot_util_Position$method$line$cff1e597e2cfa9a2(_jc_env *, struct _jc_polyglot_util_Position$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Position$method$nameAndLineString$834b34befb17e6ff(_jc_env *, struct _jc_polyglot_util_Position$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Position$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_util_Position$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Position$method_info$column$370206cd3cb25d90;
extern _jc_method _jc_polyglot_util_Position$method_info$file$4a28a30360790222;
extern _jc_method _jc_polyglot_util_Position$method_info$line$cff1e597e2cfa9a2;
extern _jc_method _jc_polyglot_util_Position$method_info$nameAndLineString$834b34befb17e6ff;
extern _jc_method _jc_polyglot_util_Position$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_util_Position$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_util_Position$vmethods {
	jint	(*column$370206cd3cb25d90)(_jc_env *, struct _jc_polyglot_util_Position$object *);
	struct _jc_java_lang_String$object	*(*file$4a28a30360790222)(_jc_env *, struct _jc_polyglot_util_Position$object *);
	jint	(*line$cff1e597e2cfa9a2)(_jc_env *, struct _jc_polyglot_util_Position$object *);
	struct _jc_java_lang_String$object	*(*nameAndLineString$834b34befb17e6ff)(_jc_env *, struct _jc_polyglot_util_Position$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_util_Position$object *);
};

// Vtable
struct _jc_polyglot_util_Position$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Position$vmethods	polyglot_util_Position;
};

// Vtype
struct _jc_polyglot_util_Position$vtype {
	_jc_type			type;
	_jc_polyglot_util_Position$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Position$sub_refs {
	struct _jc_java_lang_String$object	*file;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Position$refs {
    _jc_polyglot_util_Position$sub_refs	polyglot_util_Position;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Position$sub_nonrefs {
	jint	line;
	jint	column;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Position$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Position$sub_nonrefs	polyglot_util_Position;
};

// Object instance structure
struct _jc_polyglot_util_Position$object {
	_jc_polyglot_util_Position$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Position$vtype	*vtype;
	_jc_polyglot_util_Position$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Position$vtype _jc_polyglot_util_Position$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Position, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Position$class_object;

#endif	/* _JC_polyglot_util_Position_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Position.h <==
// public class polyglot.util.Position

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Position_H_
#define _JC_polyglot_util_Position_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_util_Position$sub_refs	_jc_polyglot_util_Position$sub_refs;
typedef struct _jc_polyglot_util_Position$sub_nonrefs	_jc_polyglot_util_Position$sub_nonrefs;
typedef struct _jc_polyglot_util_Position$refs	_jc_polyglot_util_Position$refs;
typedef struct _jc_polyglot_util_Position$nonrefs	_jc_polyglot_util_Position$nonrefs;
typedef struct _jc_polyglot_util_Position$object	_jc_polyglot_util_Position$object;

typedef struct _jc_polyglot_util_Position$fields_struct	_jc_polyglot_util_Position$fields_struct;
typedef const struct _jc_polyglot_util_Position$vmethods	_jc_polyglot_util_Position$vmethods;
typedef const struct _jc_polyglot_util_Position$vtable	_jc_polyglot_util_Position$vtable;
typedef const struct _jc_polyglot_util_Position$vtype	_jc_polyglot_util_Position$vtype;

// Class fields structure
struct _jc_polyglot_util_Position$fields_struct {
	struct _jc_polyglot_util_Position$object	*COMPILER__5fGENERATED;
	jlong	serialVersionUID;
	jint	UNKNOWN;
};
extern _jc_polyglot_util_Position$fields_struct _jc_polyglot_util_Position$class_fields;

// Constructors
extern void _jc_polyglot_util_Position$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_Position$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_Position$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_Position$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_util_Position$method$column$370206cd3cb25d90(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Position$method$file$4a28a30360790222(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_Position$method$line$cff1e597e2cfa9a2(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Position$method$nameAndLineString$834b34befb17e6ff(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Position$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Position$method_info$column$370206cd3cb25d90;
extern _jc_method _jc_polyglot_util_Position$method_info$file$4a28a30360790222;
extern _jc_method _jc_polyglot_util_Position$method_info$line$cff1e597e2cfa9a2;
extern _jc_method _jc_polyglot_util_Position$method_info$nameAndLineString$834b34befb17e6ff;
extern _jc_method _jc_polyglot_util_Position$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_util_Position$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_Position$vmethods {
	jint	(*column$370206cd3cb25d90)(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*file$4a28a30360790222)(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
	jint	(*line$cff1e597e2cfa9a2)(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*nameAndLineString$834b34befb17e6ff)(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_Position$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Position$vmethods	polyglot_util_Position;
};

// Vtype
struct _jc_polyglot_util_Position$vtype {
	_jc_type			type;
	_jc_polyglot_util_Position$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Position$sub_refs {
	struct _jc_java_lang_String$object	*file;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Position$refs {
    _jc_polyglot_util_Position$sub_refs	polyglot_util_Position;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Position$sub_nonrefs {
	jint	line;
	jint	column;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Position$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Position$sub_nonrefs	polyglot_util_Position;
};

// Object instance structure
struct _jc_polyglot_util_Position$object {
	_jc_polyglot_util_Position$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Position$vtype	*vtype;
	_jc_polyglot_util_Position$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Position$vtype _jc_polyglot_util_Position$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Position, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Position$class_object;

#endif	/* _JC_polyglot_util_Position_H_ */
